@@ -476,7 +476,7 @@ class Video(QtGui.QWidget):
 				preview=""
 			else:
 				preview="tee name=t1 ! queue ! xvimagesink  sync=false t1. ! queue !"
-			self.audio_pipeline = gst.parse_launch("v4l2camsrc ! queue ! ffmpegcolorspace ! "+preview+" videoscale ! video/x-raw-yuv,"+str(self.comboBox.currentText())+" !  theoraenc quality=16 ! queue ! oggmux name=mux "+sndarch+" ! volume name=\"volume0\"  ! audio/x-raw-int,rate=8000,channels=1,depth=8 ! queue ! audioconvert ! vorbisenc ! queue ! mux. mux. ! queue ! shout2send ip="+self.server+" port="+self.port+" password="+self.pw+" mount=/"+self.mount)
+			self.audio_pipeline = gst.parse_launch("v4l2camsrc ! queue ! ffmpegcolorspace ! "+preview+" videoscale ! video/x-raw-yuv,"+str(self.comboBox.currentText())+" !  theoraenc quality=16 ! queue ! oggmux name=mux "+sndarch+" ! audio/x-raw-int,rate=8000,channels=1,depth=8 ! queue ! audioconvert ! vorbisenc ! queue ! mux. mux. ! queue ! shout2send ip="+self.server+" port="+self.port+" password="+self.pw+" mount=/"+self.mount)
 			self.volumesrc=self.audio_pipeline.get_by_name("volume0")
 			
 			
